@@ -1,11 +1,11 @@
 from PyQt5.QtCore import Qt
 from PyQt5.QtGui import *
 from PyQt5.QtWidgets import *
-from synesthesia.wsl import *
-from synesthesia.image_helper import *
+from wsl import *
+from image_helper import *
 from PIL.ImageQt import ImageQt
-from synesthesia.essentia_helper import *
-import glob, os, shutil, os.path
+from essentia_helper import *
+import glob, os, shutil, os, sys
 
 
 class Window(QWidget):
@@ -13,20 +13,20 @@ class Window(QWidget):
         super().__init__()
         # set widow titles
         self.setWindowTitle(' ')
-        self.setWindowIcon(QIcon('synesthesia/images/title_logo.png'))
+        self.setWindowIcon(QIcon('./images/title_logo.png'))
 
         # resize window
         self.resize(610, 580)
 
         # set the logo
-        logo_file = QPixmap('main_logo.svg')
+        logo_file = QPixmap('./images/main_logo.svg')
         logo_file = logo_file.scaled(400, 150)
         self.logo = QLabel(self)
         self.logo.setPixmap(logo_file)
         self.logo.move(110, 0)
 
         # line seperators
-        sep = QPixmap('synesthesia/images/line.png')
+        sep = QPixmap('./images/line.png')
         sep = sep.scaled(610, 1)
         self.mid_line = QLabel(self)
         self.mid_line.setPixmap(sep)
@@ -160,16 +160,10 @@ class Window(QWidget):
         # Other Slider
         self.bs_lbl = QLabel(self)
 
-        print("jah test43")
+
 
         print(os.getcwd())
 
-        files = [f for f in os.listdir('.') if os.path.isfile(f)]
-        for f in files:
-            print(f)
-
-
-
         bsVar = "bleh"
         try:
             with open("infile.txt", "rb") as file:
@@ -248,6 +242,8 @@ class Window(QWidget):
         self.result.setPixmap(proc_img)
         self.result.adjustSize()
 
+
+
 def main_func():
     set_display_to_host()
     # instantiate application and create a window
@@ -258,6 +254,10 @@ def main_func():
     window.show()
     app.exec()
 
+def pmain_func():
+    os.chdir('synesthesia')
+    print("jah test47")
+    main_func()
 
 
 if __name__ == '__main__':
